/* static-resources/lprint-en.strings */
static const char * const lprint_en_strings =
"\"media.na_index-3x5_3x5in\" = \"3 x 5ʺ Label\";\n"
"\"media.na_index-4x6_4x6in\" = \"4 x 6ʺ Label\";\n"
"\"media.oe_1.25x0.25-label_1.25x0.25in\" = \"1-1/4 x 1/4ʺ Label\";\n"
"\"media.oe_1.25x2.25-label_1.25x2.25in\" = \"1-1/4 x 2-1/4ʺ Label\";\n"
"\"media.oe_1.5x0.25-label_1.5x0.25in\" = \"1-1/2 x 1/4ʺ Label\";\n"
"\"media.oe_1.5x0.5-label_1.5x0.5in\" = \"1-1/2 x 1/2ʺ Label\";\n"
"\"media.oe_1.5x1-label_1.5x1in\" = \"1-1/2 x 1ʺ Label\";\n"
"\"media.oe_1.5x2-label_1.5x2in\" = \"1-1/2 x 2ʺ Label\";\n"
"\"media.oe_2-part-internet-postage-label_2.25x7.5in\" = \"2-1/4 x 7-1/2ʺ 2-Part Internet Postage Label\";\n"
"\"media.oe_2-up-address-label_2.25x3.5in\" = \"2-1/4 x 3-1/2ʺ 2-Up Address Label\";\n"
"\"media.oe_2-up-file-folder-label_1.125x3.4375in\" = \"1-1/8 x 4-7/16ʺ 2-up File Folder Label\";\n"
"\"media.oe_2.25x0.5-label_2.25x0.5in\" = \"2-1/4 x 1/2ʺ Label\";\n"
"\"media.oe_2.25x0.5-label_2.25xin\" = \"2-1/4 x 1/2ʺ Label\";\n"
"\"media.oe_2.25x1.25-label_2.25x1.25in\" = \"2-1/4 x 1-1/4ʺ Label\";\n"
"\"media.oe_2.25x1.25-label_2.25xin\" = \"2-1/4 x 1-1/4ʺ Label\";\n"
"\"media.oe_2.25x4-label_2.25x4in\" = \"2-1/4 x 4ʺ Label\";\n"
"\"media.oe_2.25x5.5-label_2.25x5.5in\" = \"2-1/4 x 5-1/2ʺ Label\";\n"
"\"media.oe_2.38x5.5-label_2.38x5.5in\" = \"2-3/8 x 5-1/2ʺ Label\";\n"
"\"media.oe_2.5x1-label_2.5x1in\" = \"2-1/2 x 1ʺ Label\";\n"
"\"media.oe_2.5x2-label_2.5x2in\" = \"2-1/2 x 2ʺ Label\";\n"
"\"media.oe_2.75x1.25-label_2.75x1.25in\" = \"2-3/4 x 1-1/4ʺ Label\";\n"
"\"media.oe_2.9x1-label_2.9x1in\" = \"2.9 x 1ʺ Label\";\n"
"\"media.oe_2x0.37-label_2x0.37in\" = \"2 x 0.37ʺ Label\";\n"
"\"media.oe_2x0.5-label_2x0.5in\" = \"2 x 1/2ʺ Label\";\n"
"\"media.oe_2x1-label_2x1in\" = \"2 x 1ʺ Label\";\n"
"\"media.oe_2x1.25-label_2x1.25in\" = \"2 x 1-1/4ʺ Label\";\n"
"\"media.oe_2x2-label_2x2in\" = \"2 x 2ʺ Label\";\n"
"\"media.oe_2x3-label_2x3in\" = \"2 x 3ʺ Label\";\n"
"\"media.oe_2x4-label_2x4in\" = \"2 x 4ʺ Label\";\n"
"\"media.oe_2x5.5-label_2x5.5in\" = \"2 x 5-1/2ʺ Label\";\n"
"\"media.oe_3-part-postage-label_2.25x7in\" = \"2-1/4 x 7ʺ 3-Part Postage Label\";\n"
"\"media.oe_3.25x2-label_3.25x2in\" = \"3-1/4 x 2ʺ Label\";\n"
"\"media.oe_3.25x5-label_3.25x5in\" = \"3-1/4 x 5ʺ Label\";\n"
"\"media.oe_3.25x5.5-label_3.25x5.5in\" = \"3-1/4 x 5-1/2ʺ Label\";\n"
"\"media.oe_3.25x5.83-label_3.25x5.83in\" = \"3-1/4 x 5-13/16ʺ Label\";\n"
"\"media.oe_3.25x7.83-label_3.25x7.83in\" = \"3-1/4 x 7-13/16ʺ Label\";\n"
"\"media.oe_3.5x1-label_3.5x1in\" = \"3-1/2 x 1ʺ Label\";\n"
"\"media.oe_30859-paint-can-label_2.25x3.125in\" = \"2-1/4 x 3-1/8ʺ Paint Can Label\";\n"
"\"media.oe_3x1-label_3x1in\" = \"3 x 1ʺ Label\";\n"
"\"media.oe_3x1.25-label_3x1.25in\" = \"3 x 1-1/4ʺ Label\";\n"
"\"media.oe_3x2-label_3x2in\" = \"3 x 2ʺ Label\";\n"
"\"media.oe_3x3-label_3x3in\" = \"3 x 3ʺ Label\";\n"
"\"media.oe_3x5-label_3x5in\" = \"3 x 5ʺ Label\";\n"
"\"media.oe_4x1-label_4x1in\" = \"4 x 1ʺ Label\";\n"
"\"media.oe_4x13-label_4x13in\" = \"4 x 13ʺ Label\";\n"
"\"media.oe_4x2-label_4x2in\" = \"4 x 2ʺ Label\";\n"
"\"media.oe_4x3-label_4x3in\" = \"4 x 3ʺ Label\";\n"
"\"media.oe_4x4-label_4x4in\" = \"4 x 4ʺ Label\";\n"
"\"media.oe_4x5-label_4x5in\" = \"4 x 5ʺ Label\";\n"
"\"media.oe_4x6-label_4x6in\" = \"4 x 6ʺ Label\";\n"
"\"media.oe_4x6.5-label_4x6.5in\" = \"4 x 6-1/2ʺ Label\";\n"
"\"media.oe_4x7.83-label_4x7.83in\" = \"4 x 7-13/16 Label\";\n"
"\"media.oe_4x8-label_4x8in\" = \"4 x 8ʺ Label\";\n"
"\"media.oe_6x1-label_6x1in\" = \"6 x 1ʺ Label\";\n"
"\"media.oe_6x13-label_6x13in\" = \"6 x 13ʺ Label\";\n"
"\"media.oe_6x2-label_6x2in\" = \"6 x 2ʺ Label\";\n"
"\"media.oe_6x3-label_6x3in\" = \"6 x 3ʺ Label\";\n"
"\"media.oe_6x4-label_6x4in\" = \"6 x 4ʺ Label\";\n"
"\"media.oe_6x5-label_6x5in\" = \"6 x 5ʺ Label\";\n"
"\"media.oe_6x6-label_6x6in\" = \"6 x 6ʺ Label\";\n"
"\"media.oe_6x6.5-label_6x6.5in\" = \"6 x 6-1/2ʺ Label\";\n"
"\"media.oe_8x1-label_8x1in\" = \"8 x 1ʺ Label\";\n"
"\"media.oe_8x13-label_8x13in\" = \"8 x 13ʺ Label\";\n"
"\"media.oe_8x2-label_8x2in\" = \"8 x 2ʺ Label\";\n"
"\"media.oe_8x3-label_8x3in\" = \"8 x 3ʺ Label\";\n"
"\"media.oe_8x4-label_8x4in\" = \"8 x 4ʺ Label\";\n"
"\"media.oe_8x5-label_8x5in\" = \"8 x 5ʺ Label\";\n"
"\"media.oe_8x6-label_8x6in\" = \"8 x 6ʺ Label\";\n"
"\"media.oe_8x6.5-label_8x6.5in\" = \"8 x 6-1/2ʺ Label\";\n"
"\"media.oe_address-label_1.125x3.5in\" = \"1-1/8 x 3-1/2ʺ Address Label\";\n"
"\"media.oe_barcode-label_0.75x2.5in\" = \"3/4 x 2-1/2ʺ Barcode Label\";\n"
"\"media.oe_book-spine-label_1x1.5in\" = \"1 x 1-1/2ʺ Book Spine Label\";\n"
"\"media.oe_continuous-label_2.125x3600in\" = \"2-1/8ʺ Continuous Label\";\n"
"\"media.oe_dk1201-address_1.1x3.5in\" = \"DK1201 28 x 89mm Address Label\";\n"
"\"media.oe_dk1202-shipping_2.4x3.9in\" = \"DK1202 61 x 99mm Shipping Label\";\n"
"\"media.oe_dk1203-file-folder_0.66x3.4in\" = \"DK1203 17 x 86mm File Folder Label\";\n"
"\"media.oe_dk1204-multi-purpose_0.66x2.1in\" = \"DK1204 17 x 53mm Multipurpose Label\";\n"
"\"media.oe_dk1207-cd-dvd_2.2x2.2in\" = \"DK1207 56mm CD/DVD Label\";\n"
"\"media.oe_dk1208-large-address_1.4x3.5in\" = \"DK1208 36 x 89mm Large Address Label\";\n"
"\"media.oe_dk1209-small-address_1.1x2.4in\" = \"DK1209 28 x 61mm Small Address Label\";\n"
"\"media.oe_dk1219-round_0.47x0.47in\" = \"DK1219 12mm Round Label\";\n"
"\"media.oe_dk1240-large-multi-purpose_1.9x4in\" = \"DK1240 48 x 102mm Large Multipurpose Label\";\n"
"\"media.oe_file-folder-label_0.5625x3.4375in\" = \"9/16 x 3-7/16ʺ File Folder Label\";\n"
"\"media.oe_hanging-file-tab-insert_0.5625x2in\" = \"9/16 x 2ʺ Hanging File Tab Insert Label\";\n"
"\"media.oe_internet-postage-confirmation-label_2.3125x10.5in\" = \"2-5/16 x 10-1/2ʺ Internet Postage Confirmation Label\";\n"
"\"media.oe_internet-postage-label_1.25x1.625in\" = \"1-1/4 x 1-5/8ʺ Internet Postage Label\";\n"
"\"media.oe_internet-postage-label_2.3125x7in\" = \"2-3/8 x 7ʺ Internet Postage Label\";\n"
"\"media.oe_lg-address-label_1.4x3.5in\" = \"1-4/10 x 3-1/2ʺ Large Address Label\";\n"
"\"media.oe_lg-multipurpose-label_2.125x.75in\" = \"2-1/8 x 3/4ʺ Large Multipurpose Label\";\n"
"\"media.oe_library-barcode-label_0.5x1.875in\" = \"1/2 x 1-7/8ʺ Library Barcode Label\";\n"
"\"media.oe_md-appointment-card_2x3.5in\" = \"2 x 3-1/2ʺ Medium Appointment Card\";\n"
"\"media.oe_md-multipurpose-label_2.25x1.25in\" = \"2-1/4 x 1/1/4ʺ Medium Multipurpose Label\";\n"
"\"media.oe_media-label_2.25x2.25in\" = \"2-1/4 x 2-1/4ʺ Media Label\";\n"
"\"media.oe_medium-1in-tape_0.5x1in\" = \"1/2 x 1ʺ Tape\";\n"
"\"media.oe_medium-2in-tape_0.5x2in\" = \"1/2 x 2ʺ Tape\";\n"
"\"media.oe_medium-3in-tape_0.5x3in\" = \"1/2 x 3ʺ Tape\";\n"
"\"media.oe_multipurpose-label_2x2.3125in\" = \"2 x 2-5/16ʺ Multipurpose Label\";\n"
"\"media.oe_name-badge-label_2.25x4in\" = \"2-1/4 x 4ʺ Name Badge Label\";\n"
"\"media.oe_price-tag-label_0.9375x0.875in\" = \"15/16 x 7/8ʺ Price Tag Label\";\n"
"\"media.oe_return-address-label_0.75x2in\" = \"3/4 x 2ʺ Return Address Label\";\n"
"\"media.oe_shipping-label_2.125x4in\" = \"2-1/8 x 4ʺ Shipping Label\";\n"
"\"media.oe_shipping-label_2.3125x4in\" = \"2-5/16 x 4ʺ Shipping Label\";\n"
"\"media.oe_sm-multipurpose-label_1x2.125in\" = \"1 x 2-1/8ʺ Small Multipurpose Label\";\n"
"\"media.oe_square-multipurpose-label_1x1in\" = \"1ʺ Square Multipurpose Label\";\n"
"\"media.oe_thin-1in-tape_0.25x1in\" = \"1/4 x 1ʺ Tape\";\n"
"\"media.oe_thin-2in-tape_0.25x2in\" = \"1/4 x 2ʺ Tape\";\n"
"\"media.oe_thin-3in-tape_0.25x3in\" = \"1/4 x 3ʺ Tape\";\n"
"\"media.oe_thin-multipurpose-label_0.375x2.8125in\" = \"3/8 x 2-13/16ʺ Thin Multipurpose Label\";\n"
"\"media.oe_thinner-1in-tape_0.375x1in\" = \"3/8 x 1ʺ Tape\";\n"
"\"media.oe_thinner-2in-tape_0.375x2in\" = \"3/8 x 2ʺ Tape\";\n"
"\"media.oe_thinner-3in-tape_0.375x3in\" = \"3/8 x 3ʺ Tape\";\n"
"\"media.oe_video-spine-label_0.75x5.875in\" = \"3/4 x 5-7/8ʺ Video Spine Label\";\n"
"\"media.oe_video-top-label_1.8x3.1in\" = \"1.8 x 3.1ʺ Video Top Label\";\n"
"\"media.oe_wide-1in-tape_1x1in\" = \"1 x 1ʺ Tape\";\n"
"\"media.oe_wide-2in-tape_1x2in\" = \"1 x 2ʺ Tape\";\n"
"\"media.oe_wide-3in-tape_1x3in\" = \"1 x 3ʺ Tape\";\n"
"\"media.oe_wider-1in-tape_0.75x1in\" = \"3/4 x 1ʺ Tape\";\n"
"\"media.oe_wider-2in-tape_0.75x2in\" = \"3/4 x 2ʺ Tape\";\n"
"\"media.oe_wider-3in-tape_0.75x3in\" = \"3/4 x 3ʺ Tape\";\n"
"\"media.om_35mm-slide_9x37mm\" = \"35mm Slide Label\";\n"
"\"media.om_4-part-label_48x96mm\" = \"48 x 96mm 4-Part Label\";\n"
"\"media.om_8mm-spine_9x66mm\" = \"8mm Spine Label\";\n"
"\"media.om_address-large_35x83mm\" = \"35 x 83mm Large Address Label\";\n"
"\"media.om_address-small_24x83mm\" = \"24 x 83mm Small Address Label\";\n"
"\"media.om_cut-hanging-13_32x78mm\" = \"32 x 78mm 1/3 Cut Hanging File Folder Label\";\n"
"\"media.om_cut-hanging-15_32x40mm\" = \"32 x 40mm 1/5 Cut Hanging File Folder Label\";\n"
"\"media.om_diskette_48x64mm\" = \"48 x 64mm Diskette Label\";\n"
"\"media.om_diskette_54x70mm\" = \"54 x 70mm Diskette Label\";\n"
"\"media.om_euro-file-folder_39x49mm\" = \"39 x 49mm Euro File Folder Label\";\n"
"\"media.om_euro-folder-narrow_38x186mm\" = \"38 x 186mm Euro Narrow File Folder Label\";\n"
"\"media.om_euro-folder-wide_48x186mm\" = \"48 x 186mm Euro Wide File Folder Label\";\n"
"\"media.om_euro-name-badge-large_48x79mm\" = \"48 x 79mm Euro Large Name Badge Label\";\n"
"\"media.om_euro-name-badge_38x67mm\" = \"38 x 67mm Euro Name Badge Label\";\n"
"\"media.om_file-folder_13x81mm\" = \"13 x 81mm File Folder Label\";\n"
"\"media.om_jewelry_27x48mm\" = \"27 x 48mm Jewelry Label\";\n"
"\"media.om_media-badge_48x64mm\" = \"48 x 64mm Media Badge Label\";\n"
"\"media.om_multi-purpose_24x44mm\" = \"24 x 44mm Multipurpose Label\";\n"
"\"media.om_retail-label_32x37mm\" = \"32 x 37mm Retail Label\";\n"
"\"media.om_return_16x43mm\" = \"16 x 43mm Return Label\";\n"
"\"media.om_round_22x24mm\" = \"22mm Round Label\";\n"
"\"media.om_shipping_48x96mm\" = \"48 x 96mm Shipping Label\";\n"
"\"media.om_top-coated-paper_48x140mm\" = \"48 x 140mm Top Coated Paper\";\n"
"\"media.om_vhs-face_45x72mm\" = \"45 x 72mm VHS Face Label\";\n"
"\"media.om_vhs-spine_18x141mm\" = \"18 x 141mm VHS Spine Label\";\n"
"\"media.om_zip-disk_48x55mm\" = \"48 x 55mm Zip Disk Label\";\n"
"\"New Custom Size\" = \"New Custom Size\";\n"
;
